--------------------------------------------------------------------------------
--                   Zolan's Anchors Away (Addon Menu)
--------------------------------------------------------------------------------

local ZAA       = Zolan_AA
local AddonMenu = ZAA.AddonMenu
AddonMenu.Vars  = {}

-- Localize as much as we can to avoid global lookups.
local LibStub   = LibStub

AddonMenu.colors = {
    ["gold"]       = "|cFFD700", -- Gold
    ["faded_gold"] = "|c998100", -- Faded Gold
    ["light_blue"] = "|c88DDDD", -- Light Blue
    ["faded_blue"] = "|c44AAAA"  -- Faded Blue
}

AddonMenu.Vars.titleColor   = AddonMenu.colors.gold
AddonMenu.Vars.header1Color = AddonMenu.colors.gold
AddonMenu.Vars.header2Color = AddonMenu.colors.faded_gold
AddonMenu.Vars.header3Color = AddonMenu.colors.faded_blue
AddonMenu.Vars.header4Color = AddonMenu.colors.light_blue

AddonMenu.LAM = LibStub("LibAddonMenu-1.0")
AddonMenu.controlPanel = AddonMenu.LAM:CreateControlPanel("Zolan_Addons_ControlPanel", AddonMenu.Vars.titleColor .. "Zolan's Addons")

function AddonMenu.getBooleanOption(optionName)
    ZAA.debug("AddonMenu -> getBooleanOption [" .. optionName .. "]")
    return ZAA.savedVars[optionName]
end

function AddonMenu.toggleBooleanOption(optionName)
    ZAA.debug("AddonMenu -> toggleBooleanOption [" .. optionName .. "]")
    local newValue = not ZAA.savedVars[optionName]
    ZAA.savedVars[optionName] = newValue
end

function AddonMenu.initializeAddonMenu()
    ZAA.debug("AddonMenu -> initializeAddonMenu")

    AddonMenu.LAM:AddHeader(AddonMenu.controlPanel,
        "ZAA_AnchorsAwayHeader",
        AddonMenu.Vars.header1Color .. "ZOLAN'S ANCHORS AWAY"
          .. AddonMenu.Vars.header2Color .. ' - ' .. AddonMenu.Vars.header3Color
          .. ZAA.appVersion
    )

    AddonMenu.LAM:AddCheckbox(AddonMenu.controlPanel,
        "ZAA_Enabled",
        "Enable Anchors Away",
        "Enable or disable ALL features of Zolan's Anchors Away.",
        function () return AddonMenu.getBooleanOption('enabled') end,
        function () AddonMenu.toggleBooleanOption('enabled')     end
    )
    AddonMenu.LAM:AddCheckbox(AddonMenu.controlPanel,
        "ZAA_Debug",
        "Enable Debugging",
        "You almost certainly want this disabled. Enabling it will "
          .. "cause a massive amount of text in your chat box.",
        function () return AddonMenu.getBooleanOption('debug') end,
        function () AddonMenu.toggleBooleanOption('debug')     end
    )
    AddonMenu.subPanelNotify = AddonMenu.LAM:AddSubMenu(
        AddonMenu.controlPanel,
        'ZAA_SubPanelNotify',
        AddonMenu.Vars.header4Color..'Manage Notification Settings',
        'Open Notification Settings'
    )
    AddonMenu.subPanelNotify:GetOwningWindow():SetDimensions(600,120)

    AddonMenu.LAM:AddCheckbox(AddonMenu.subPanelNotify,
        "ZAA_Notify",
        "Enable Notifications",
        "Enable or disable notifications that it blocked an error.",
        function () return AddonMenu.getBooleanOption('notify') end,
        function () AddonMenu.toggleBooleanOption('notify')     end
    )
    AddonMenu.LAM:AddCheckbox(AddonMenu.subPanelNotify,
        "ZAA_ShowErrors",
        "Enable Show Problem Causing Errors",
        "Enable or disable listing errors that are likely breaking this addon.",
        function () return AddonMenu.getBooleanOption('showErrors') end,
        function () AddonMenu.toggleBooleanOption('showErrors')     end
    )
end
