--------------------------------------------------------------------------------
--                   Zolan's Anchors Away (Handlers)
--------------------------------------------------------------------------------

local ZAA       = Zolan_AA
local AddonMenu = ZAA.AddonMenu
local Handler   = ZAA.Handler
local Util      = ZAA.Util

-- ZO
local EVENT_ADD_ON_LOADED     = EVENT_ADD_ON_LOADED
local EVENT_LUA_ERROR         = EVENT_LUA_ERROR
local EVENT_MANAGER           = EVENT_MANAGER
local EVENT_PLAYER_ACTIVATED  = EVENT_PLAYER_ACTIVATED
local d                       = d
local ZO_UIErrors_HideCurrent = ZO_UIErrors_HideCurrent
-- Lua
local string                  = string

function Handler.handleOnAddOnLoad(event, addonName)
    if not ZAA.loaded then ZAA.loadVariables() end

    if addonName ~= ZAA.addonName then return end

    d("Zolan's Anchors Away: Loaded")

    if ZAA.otherErrorCount == nil then ZAA.otherErrorCount = 0 end
    if ZAA.suppressCount   == nil then ZAA.suppressCount   = 0 end
    if ZAA.playerActivated == nil then ZAA.playerActivated = 0 end

    AddonMenu.initializeAddonMenu()

    EVENT_MANAGER:UnregisterForEvent("ZAA_OnAddOnLoad", EVENT_ADD_ON_LOADED)
    Handler.loadEventHandlers()
end

function Handler.handlePlayerActivated()
    ZAA.debug("Handler -> handlePlayerActivated")

    ZAA.playerActivated = 1 -- Now activated so any further anchor errors can
                            -- be handled by the LuaError handler itself.

    local message = string.format(
        "%s%s Version %s%s%s Loaded.",
        ZAA.Vars.outputHeader,
        ZAA.Vars.defaultColor,
        ZAA.Vars.currencyColor,
        ZAA.appVersion,
        ZAA.Vars.defaultColor
    )

    if ZAA.otherErrorCount > 0 then
        message = message..' |cff0000[ERROR: You have encountered '
          ..ZAA.otherErrorCount..' addon error(s) not related to anchors.  This causes Anchors '
          ..'Away to not work in most cases.  This also means you have a broken addon. '
          ..'Please fix your other problem before submitting a bug for Anchors Away.]'
    elseif ZAA.suppressCount > 0 then
        if ZAA.savedVars.notify then
            message = message..' |cff0000[Suppressed '..ZAA.suppressCount..' Anchor Error(s)]'
        end

        for cnt = 1, ZAA.suppressCount do
            ZO_UIErrors_HideCurrent()
        end
    end

    if ZAA.otherErrorCount > 0 and ZAA.savedVars.showErrors then
        message = message.."\n"

        message = message..string.format(
            "%s%s ADDITIONAL ERROR TEXT BELOW HERE",
            ZAA.Vars.outputHeader,
            ZAA.Vars.defaultColor
        ).."\n"

        for cnt = 1, #ZAA.otherErrors do
            message = message..ZAA.otherErrors[cnt].."\n"
        end

        message = message..string.format(
            "%s%s ADDITIONAL ERROR TEXT ABOVE HERE",
            ZAA.Vars.outputHeader,
            ZAA.Vars.defaultColor
        ).."\n"
    end

    Util.sendMessageToChat(message)

    EVENT_MANAGER:UnregisterForEvent("ZAA_PlayerActivated", EVENT_PLAYER_ACTIVATED)
end

function Handler.handleLuaError(errorID, message)
    if ZAA ~= nil and ZAA.savedVars ~= nil then
        if ZAA.savedVars.debug then
            ZAA.debug("Handler -> handleLuaError -> "..errorID.." -> "..message)
        end
    else
        d("Zolan's Anchors Away: Handler -> handleLuaError -> "..errorID.." -> "..message)
    end

    if ZAA.otherErrorCount == nil then ZAA.otherErrorCount =  0 end
    if ZAA.otherErrors     == nil then ZAA.otherErrors     = {} end
    if ZAA.suppressCount   == nil then ZAA.suppressCount   =  0 end

    -- This will presently only work with english clients.
    -- Relying on errorID 65538 is not reliable.  Heh.
    if not message:match('Too many anchors processed.') then
        ZAA.otherErrorCount = ZAA.otherErrorCount + 1

        table.insert(ZAA.otherErrors, message)

        return
    end

    ZAA.suppressCount = ZAA.suppressCount + 1

    if ZAA.savedVars ~= nil and (not ZAA.savedVars.enabled) then return end

    if ZAA.playerActivated == 1 then
        if ZAA.savedVars.notify then
            local suppressMessage = '|cff0000[Suppressed Anchor Error]'

            Util.sendMessageToChat(string.format(
                "%s%s %s",
                ZAA.Vars.outputHeader,
                ZAA.Vars.defaultColor,
                suppressMessage
            ))
        end

        ZO_UIErrors_HideCurrent()
    end
end

function Handler.loadEventHandlers()
    ZAA.debug("Handler -> loadEventHandlers")
    EVENT_MANAGER:RegisterForEvent("ZAA_PlayerActivated", EVENT_PLAYER_ACTIVATED, Handler.handlePlayerActivated)
end

EVENT_MANAGER:RegisterForEvent("ZAA_LuaError",    EVENT_LUA_ERROR,     Handler.handleLuaError)
EVENT_MANAGER:RegisterForEvent("ZAA_OnAddOnLoad", EVENT_ADD_ON_LOADED, Handler.handleOnAddOnLoad)
